<TS version="2.1" language="bs">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Desni klik za uređivanje adrese ili oznake</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Napravite novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Kopirajte trenutno odabranu adresu u sistemski meduspremnik</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopirajte</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Zatvorite</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Izbrišite trenutno odabranu odresu sa liste</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Unesite adresu ili oznaku za pretragu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Izvezite</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">Iz&amp;brišite</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Izaberite adresu na koju ćete poslati novac</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Izaberite adresu na koju ćete primiti novac</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Izaberite</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ovo su vaše Bitcoin adrese za slanje novca. Uvijek provjerite iznos i adresu primaoca prije slanja novca.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Ovo su vaše Bitcoin adrese za primanje uplata. Upotrijebite dugme 'Stvori novu adresu prijema' na kartici primanja da biste kreirali nove adrese. Potpisivanje je moguće samo s adresama tipa 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Kopirajte adresu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopirajte &amp;ozanku</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Uredite</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Izvezite listu adresa</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Datoteka odvojena zarezom</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Došlo je do greške kod spašavanja liste adresa na %1. Molimo pokušajte ponovo.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Izvoz neuspješan</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nema oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Dijalog Lozinke</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Unesi lozinku</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nova lozinka</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Ponovi novu lozinku</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Prikaži lozinku</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Šifriraj novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Za otključavanje novčanika za ovu operaciju potrebna je lozinka vašeg novčanika.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Otključajte novčanik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Promijenite lozinku</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Potvrdite šifriranje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Upozorenje: Ako šifrirate novčanik i izgubite lozinku, &lt;b&gt;IZGUBIT ĆETE SVE SVOJE BITKOINE!&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Jeste li sigurni da želite šifrirati novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Novčanik šifriran</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Unesite novu lozinku za novčanik.&lt;br/&gt;Upotrijebite lozinku od &lt;b&gt;deset ili više nasumičnih znakova&lt;/b&gt; ili &lt;b&gt;osam ili više riječi&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Unesite staru i novu lozinku za novčanik.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Imajte na umu da šifriranje vašeg novčanika ne može u potpunosti zaštititi vaše bitcoine od krađe zlonamjernim softverom koji zarazi vaš računar.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Novčanik za šifriranje</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Novčanik će uskoro biti šifriran.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Vaš novčanik je sada šifriran.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">VAŽNO: Sve prethodne sigurnosne kopije datoteke novčanika koje ste napravili treba zamijeniti novo generiranom, šifriranom datotekom novčanika. Iz sigurnosnih razloga, prethodne sigurnosne kopije nešifrirane datoteke novčanika postat će beskorisne čim započnete koristiti novi, šifrirani novčanik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Šifriranje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Šifriranje novčanika nije uspjelo zbog interne greške. Vaš novčanik nije šifriran.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Upisane lozinke se ne podudaraju.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Otključavanje novčanika nije uspjelo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Lozinka unesena za dešifriranje novčanika nije ispravna.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Lozinka za novčanik uspješno je promijenjena.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Upozorenje: Tipka Caps Lock je uključena!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Zabranjeno Do</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Datoteka postavki %1 je možda oštećena ili nevažeća.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Odbegli izuzetak</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Dogodila se fatalna greška. %1 više ne može sigurno nastaviti i prestat će raditi.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Interna greška</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Dogodila se interna greška. %1 će pokušati nastaviti sigurno. Ovo je neočekivana greška koja se može prijaviti kako je opisano u nastavku.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Želite li resetirati postavke na zadane vrijednosti ili prekinuti bez unošenja promjena?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Došlo je do fatalne greške. Provjerite da li se u datoteku postavki može pisati ili pokušajte pokrenuti s -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Greška: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 još nije sigurno izašao...</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">nepoznato</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Iznos</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Pregled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Prikaži opšti pregled novčanika</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transakcije</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Pregledajte historiju transakcija</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Izlaz</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Zatvori aplikaciju</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;O %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Prikaži informacije o %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">O &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Prikaži informacije o Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Izmijenite opcije konfiguracije za %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Kreirajte novi novčanik</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Minimiziraj</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Novčanik:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Mrežna aktivnost je onemogućena.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy je &lt;b&gt;omogućen&lt;/b&gt;: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Pošaljite kovanice na Bitcoin adresu</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Izradite sigurnosnu kopiju novčanika na drugoj lokaciji</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Promijenite lozinku koja se koristi za šifriranje novčanika</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Primite</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Opcije…</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Šifrirajte privatne ključeve koji pripadaju vašem novčaniku</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Potpiši &amp;poruku…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Potpišite poruke sa svojim Bitcoin adresama da biste dokazali da ste njihov vlasnik</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Potvrdite poruke kako biste bili sigurni da su potpisane navedenim Bitcoin adresama</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Otvori &amp;URI…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Zatvori novčanik...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Napravi novčanik...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Zatvori sve novčanike...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Postavke</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Pomoć</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Alatna traka kartica</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Sinhroniziranje zaglavlja (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sinhronizacija sa mrežom...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Indeksiraju se blokovi na disku...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Procesuiraju se blokovi na disku...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Povezivanje sa kolegama…</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Zatražite uplate (generira QR kodove i bitcoin: URI-je)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Prikažite listu korištenih adresa i oznaka za slanje</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Prikažite listu korištenih adresa i oznaka za prijem</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Opcije komandne linije</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 iza</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Posljednji primljeni blok generiran je prije %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transakcije nakon ovoga još neće biti vidljive.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informacije</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">U toku</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Učitajte Djelomično Potpisanu Bitcoin Transakciju</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Učitajte djelomično potpisanu bitcoin transakciju iz međuspremnika</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Prozor čvora</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Otvorite čvor za ispravljanje pogrešaka i dijagnostičku konzolu</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Slanje adresa</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Primanje adresa</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Otvorite bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Otvorite Novčanik</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Otvorite Novčanik</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Zatvori novčanik</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Zatvori sve novčanike</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Pokažite %1 poruku za pomoć da biste dobili listu s mogućim opcijama Bitcoin naredbenog retka</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Vrijednosti maske</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Maskirajte vrijednosti na kartici Pregled</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">zadani novčanik</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Nema dostupnih novčanika</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Ime Novčanika</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Prozor</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Glavni Prozor</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 klijent</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Klikni za još radnji</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Onemogući rad mreže</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Greška: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Upozorenje: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Iznos: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Novčanik: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Tip: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Adresa: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Pošalji transakciju</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Dolazna transakcija</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">Stvaranje HD ključa je &lt;b&gt;omogućeno&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Stvaranje HD ključa je &lt;b&gt;onemogućeno&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Privatni ključ je &lt;b&gt;onemogućen&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Novčanik je &lt;b&gt;šifriran&lt;/b&gt; i trenutno je &lt;b&gt;zaključan&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Orginalna poruka:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Jedinica u kojoj se prikazuju iznosi. Kliknite za odabir druge jedinice.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Izbor Novčića</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Bajtovi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Poslije Naknade:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Promjena:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(ne)odaberi sve</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Način stabla</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Način liste</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Iznos</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Primljeno sa etiketom</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Primljeno sa adresom</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Potvrde</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Potvrđeno</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopiraj količinu</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopiraj naknadu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopiraj vrijednost poslije naknade</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopiraj bajte</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopiraj promjenu</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 zaključano)</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Može varirati +/- %1 satoshi (a) po upisu vrijednosti.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nema oznake)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">promjena iz %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(promjeni)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Kreirajte Novčanik</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Izrada novčanika nije uspjela</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Stvorite upozorenje novčanika</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">zadani novčanik</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Otvorite Novčanik</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Zatvori novčanik</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Zatvori sve novčanike</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Kreirajte Novčanik</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Ime Novčanika</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Novčanik</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Šifrirajte novčanik. Novčanik će biti šifriran lozinkom po vašem izboru.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Šifrirajte Novčanik</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Napredne Opcije</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Onemogućite privatne ključeve za ovaj novčanik. Novčanici s onemogućenim privatnim ključevima neće imati privatne ključeve i ne mogu imati HD sjeme ili uvezene privatne ključeve. Ovo je idealno za novčanike za gledanje.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">Onemogućite Privatne Ključeve</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Napravite prazan novčanik. Prazni novčanici u početku nemaju privatne ključeve ili skripte. Privatni ključevi i adrese mogu se kasnije uvoziti ili postaviti HD seme.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Napravi Prazan Novčanik</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Napravi</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Uredi Adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Oznaka</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Oznaka povezana s ovim unosom liste adresa</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">Adresa povezana s ovim unosom liste adresa. Ovo se može izmijeniti samo za slanje adresa.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Nova adresa za slanje</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Uredite adresu prijema</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Uredite adresu za slanje</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Unesena adresa "%1" nije važeća Bitcoin adresa.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Adresa "%1" već postoji kao adresa primatelja s oznakom "%2" i zato se ne može dodati kao adresa za slanje.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">Unesena adresa "%1" već je u adresaru sa oznakom "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Nije moguće otključati novčanik.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Nova generacija ključeva nije uspjela.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Stvorit će se novi direktorij podataka.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">ime</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Direktorij već postoji. Dodajte %1 ako ovdje namjeravate stvoriti novi direktorij.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Put već postoji i nije direktorij.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Ovdje nije moguće stvoriti direktorij podataka.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation type="unfinished">Najmanje %1 GB podataka bit će pohranjeno u ovom direktoriju i vremenom će rasti.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">Otprilike %1 GB podataka bit će pohranjeno u ovom direktoriju.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation type="unfinished">%1 će preuzeti i pohraniti kopiju lanca Bitcoin blokova.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation type="unfinished">Novčanik će također biti pohranjen u ovom direktoriju.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation type="unfinished">Greška: Navedeni direktorij podataka "%1" ne može se kreirati.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Dobrodošli</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">Dobrodošli u %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation type="unfinished">Zato što je ovo prvi put da se program pokreće, možete odabrati gdje će %1 čuvati svoje podatke.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation type="unfinished">Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova. Brže je prvo preuzeti čitav lanac i kasnije ga obrezati. Onemogućava neke napredne funkcije.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation type="unfinished">Ako ste odlučili ograničiti skladištenje lanca blokova (obrezivanje), povijesni podaci i dalje se moraju preuzeti i obraditi, ali će se nakon toga izbrisati kako bi se smanjila upotreba diska.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">Koristite zadani direktorij podataka</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation type="unfinished">Koristite prilagođeni direktorij podataka:</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">verzija</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">O %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Opcije komandne linije</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Ne isključujte računar dok ovaj prozor ne nestane.</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Obrazac</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.</source>
        <translation type="unfinished">Nedavne transakcije možda još nisu vidljive, pa stoga stanje na vašem novčaniku može biti pogrešno. Ove će informacije biti točne nakon što se novčanik završi sa sinhronizacijom s bitcoin mrežom, kao što je detaljno opisano u nastavku.</translation>
    </message>
    <message>
        <source>Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation type="unfinished">Pokušaj trošenja bitcoina na koje utječu još uvijek ne prikazane transakcije mreža neće prihvatiti.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">Broj preostalih blokova</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Vrijeme zadnjeg bloka</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished">Napredak</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation type="unfinished">Povećanje napretka po satu</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation type="unfinished">Procijenjeno vrijeme do sinhronizacije</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Sakrij</translation>
    </message>
    <message>
        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
        <translation type="unfinished">%1 se trenutno sinhronizira. Preuzet će zaglavlja i blokove sa vršnjaka i provjeriti ih dok ne dođu do vrha lanca blokova.</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation type="unfinished">Otvorite bitcoin URI</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Opcije</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Glavno</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation type="unfinished">Automatski pokreni %1 nakon prijave u sistem.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation type="unfinished">&amp;Pokrenite %1 na sistemskoj prijavi</translation>
    </message>
    <message>
        <source>Enabling pruning significantly reduces the disk space required to store transactions. All blocks are still fully validated. Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Omogućavanje obrezivanja značajno smanjuje prostor na disku potreban za čuvanje transakcija. Svi blokovi su i dalje u potpunosti provjereni. Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova.</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">Veličina predmemorije &amp;database</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">IP adresa proxyja (npr. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation type="unfinished">Pokazuje da li se isporučeni zadani SOCKS5 proxy koristi za dosezanje vršnjaka putem ovog tipa mreže.</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation type="unfinished">Smanjite, umjesto da izađete iz aplikacije kada je prozor zatvoren. Kada je ova opcija omogućena, aplikacija će se zatvoriti tek nakon odabira Izlaz u izborniku.</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation type="unfinished">Otvorite datoteku konfiguracije %1 iz radnog direktorija.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Otvorite Konfiguracijsku Datoteku</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Vratite sve opcije klijenta na zadane.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Resetiraj Opcije</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Mreža</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Vraćanje ove postavke zahtijeva ponovno preuzimanje cijelog lanca blokova.</translation>
    </message>
    <message>
        <source>(0 = auto, &lt;0 = leave that many cores free)</source>
        <translation type="unfinished">(0 = automatski, &lt;0 = ostavi toliko jezgara slobodnim)</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Stručnjak</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation type="unfinished">Ako onemogućite trošenje nepotvrđene promjene, promjena iz transakcije neće se moći koristiti dok ta transakcija nema barem jednu potvrdu. Ovo također utječe na način izračunavanja vašeg stanja.</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation type="unfinished">Automatski otvorite port Bitcoin klijenta na ruteru. Ovo radi samo kada vaš ruter podržava UPnP i ako je omogućen.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation type="unfinished">Map port koristi &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports NAT-PMP and it is enabled. The external port could be random.</source>
        <translation type="unfinished">Automatski otvorite port Bitcoin klijenta na ruteru. Ovo radi samo kada vaš ruter podržava NAT-PMP i ako je omogućen. Vanjski port može biti nasumičan.</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">Prihvatite veze izvana.</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation type="unfinished">Povežite se s Bitcoin mrežom putem SOCKS5 proxyja.</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Port proxyja (npr. 9050)</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation type="unfinished">Koristi se za dosezanje vršnjaka putem:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Prozor</translation>
    </message>
    <message>
        <source>Show the icon in the system tray.</source>
        <translation type="unfinished">Pokažite ikonu u sistemskoj paleti.</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">Prikažite samo ikonu ladice nakon umanjivanja prozora.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation type="unfinished">Ovdje se može podesiti jezik korisničkog interfejsa. Ova postavka će stupiti na snagu nakon ponovnog pokretanja %1.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation type="unfinished">Konfiguracijski falj nije bilo moguce otvoriti.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Obrazac</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">Moguće je da su prikazane informacije zastarjele.Vaš novčanik se automatski sinhronizira sa Bitcoin mrežom nakon što je konekcija uspostavljena, ali proces nije još uvijek dovršen.</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">Nedavne transakcije</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Adresa</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Prozor čvora</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Vrijeme zadnjeg bloka</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Nije moguće otključati novčanik.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Iznos:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Novčanik:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Oznaka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nema oznake)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Količina:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Bajtovi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Poslije Naknade:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Promjena:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Sakrij</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopiraj količinu</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopiraj iznos</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopiraj naknadu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopiraj vrijednost poslije naknade</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopiraj bajte</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopiraj promjenu</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nema oznake)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">nepoznato</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Iznos</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Oznaka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(nema oznake)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Sve</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Danas</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Ovaj mjesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Prošli mjesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Ove godine</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Datoteka odvojena zarezom</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Potvrđeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adresa</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Izvoz neuspješan</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Kreirajte novi novčanik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Greška</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">zadani novčanik</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Izvezite</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Izvezite podatke trenutne kartice u datoteku</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Replaying blocks…</source>
        <translation type="unfinished">Reprodukcija blokova…</translation>
    </message>
    <message>
        <source>Rescanning…</source>
        <translation type="unfinished">Ponovno skeniranje…</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to execute statement to verify database: %s</source>
        <translation type="unfinished">SQLiteDatabase: Izvršenje naredbe za provjeru baze podataka nije uspjelo: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to prepare statement to verify database: %s</source>
        <translation type="unfinished">SQLiteDatabase: Nije uspjela priprema naredbe za provjeru baze podataka: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Failed to read database verification error: %s</source>
        <translation type="unfinished">SQLiteDatabase: Neuspjelo čitanje greške verifikacije baze podataka: %s</translation>
    </message>
    <message>
        <source>SQLiteDatabase: Unexpected application id. Expected %u, got %u</source>
        <translation type="unfinished">SQLiteDatabase: Neočekivani ID aplikacije. Ocekivao %u, dobio %u</translation>
    </message>
    <message>
        <source>Section [%s] is not recognized.</source>
        <translation type="unfinished">Odjeljak [%s] nije prepoznat.</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Potpisivanje transakcije nije uspjelo</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" does not exist</source>
        <translation type="unfinished">Navedeni -walletdir "%s" ne postoji</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is a relative path</source>
        <translation type="unfinished">Navedeni -walletdir "%s" je relativna putanja</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is not a directory</source>
        <translation type="unfinished">Navedeni -walletdir "%s" nije direktorij</translation>
    </message>
    <message>
        <source>Specified blocks directory "%s" does not exist.</source>
        <translation type="unfinished">Navedeni direktorij blokova "%s" ne postoji.</translation>
    </message>
    <message>
        <source>Starting network threads…</source>
        <translation type="unfinished">Pokretanje mrežnih niti…</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation type="unfinished">Izvorni kod je dostupan od %s.</translation>
    </message>
    <message>
        <source>The specified config file %s does not exist</source>
        <translation type="unfinished">Navedena konfiguracijska datoteka %s ne postoji</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation type="unfinished">Iznos transakcije je premali za plaćanje naknade</translation>
    </message>
    <message>
        <source>The wallet will avoid paying less than the minimum relay fee.</source>
        <translation type="unfinished">Novčanik će izbjeći plaćanje manje od minimalne relejne naknade.</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">Ovo je eksperimentalni softver.</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation type="unfinished">Ovo je minimalna naknada za transakciju koju plaćate za svaku transakciju.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation type="unfinished">Ovo je naknada za transakciju koju ćete platiti ako pošaljete transakciju.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">Iznos transakcije je premali</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation type="unfinished">Iznosi transakcija ne smiju biti negativni</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation type="unfinished">Transakcija mora imati najmanje jednog primaoca</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Transakcija je prevelika</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %s)</source>
        <translation type="unfinished">Nije moguće povezati se na %s na ovom računaru (povezivanje je vratilo grešku %s)</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. %s is probably already running.</source>
        <translation type="unfinished">Nije moguće povezati se na %s na ovom računaru. %s vjerovatno već radi.</translation>
    </message>
    <message>
        <source>Unable to create the PID file '%s': %s</source>
        <translation type="unfinished">Nije moguće kreirati PID fajl '%s': %s</translation>
    </message>
    <message>
        <source>Unable to generate initial keys</source>
        <translation type="unfinished">Nije moguće generirati početne ključeve</translation>
    </message>
    <message>
        <source>Unable to generate keys</source>
        <translation type="unfinished">Nije moguće generirati ključeve</translation>
    </message>
    <message>
        <source>Unable to open %s for writing</source>
        <translation type="unfinished">Nije moguće otvoriti %s za pisanje</translation>
    </message>
    <message>
        <source>Unable to start HTTP server. See debug log for details.</source>
        <translation type="unfinished">Nije moguće pokrenuti HTTP server. Pogledajte dnevnik otklanjanja grešaka za detalje.</translation>
    </message>
    <message>
        <source>Unknown -blockfilterindex value %s.</source>
        <translation type="unfinished">Nepoznata vrijednost -blockfilterindex %s.</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation type="unfinished">Nepoznata vrsta adrese '%s'</translation>
    </message>
    <message>
        <source>Unknown change type '%s'</source>
        <translation type="unfinished">Nepoznata vrsta promjene '%s'</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">Nepoznata mreža navedena u -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Unknown new rules activated (versionbit %i)</source>
        <translation type="unfinished">Nepoznata nova pravila aktivirana (versionbit %i)</translation>
    </message>
    <message>
        <source>Unsupported logging category %s=%s.</source>
        <translation type="unfinished">Nepodržana kategorija logivanja %s=%s.</translation>
    </message>
    <message>
        <source>User Agent comment (%s) contains unsafe characters.</source>
        <translation type="unfinished">Komentar korisničkog agenta (%s) sadrži nesigurne znakove.</translation>
    </message>
    <message>
        <source>Verifying blocks…</source>
        <translation type="unfinished">Provjera blokova…</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">Provjera novčanika…</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart %s to complete</source>
        <translation type="unfinished">Novčanik je trebao biti prepisan: ponovo pokrenite %s da biste završili</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Nije moguće pročitati fajl postavki</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Nije moguće upisati datoteku postavki</translation>
    </message>
</context>
</TS>